@@ -72,6 +72,7 @@ const HighsInt kHighsPresolveStatusReducedToEmpty = 4;
 const HighsInt kHighsPresolveStatusTimeout = 5;
 const HighsInt kHighsPresolveStatusNullError = 6;
 const HighsInt kHighsPresolveStatusOptionsError = 7;
+const HighsInt kHighsPresolveStatusOutOfMemory = 8;
 
 const HighsInt kHighsModelStatusNotset = 0;
 const HighsInt kHighsModelStatusLoadError = 1;
@@ -105,6 +106,32 @@ const HighsInt kHighsCallbackMipSolution = 3;
 const HighsInt kHighsCallbackMipImprovingSolution = 4;
 const HighsInt kHighsCallbackMipLogging = 5;
 const HighsInt kHighsCallbackMipInterrupt = 6;
+const HighsInt kHighsCallbackMipGetCutPool = 7;
+const HighsInt kHighsCallbackMipDefineLazyConstraints = 8;
+
+const char* const kHighsCallbackDataOutLogTypeName = "log_type";
+const char* const kHighsCallbackDataOutRunningTimeName = "running_time";
+const char* const kHighsCallbackDataOutSimplexIterationCountName =
+    "simplex_iteration_count";
+const char* const kHighsCallbackDataOutIpmIterationCountName =
+    "ipm_iteration_count";
+const char* const kHighsCallbackDataOutPdlpIterationCountName =
+    "pdlp_iteration_count";
+const char* const kHighsCallbackDataOutObjectiveFunctionValueName =
+    "objective_function_value";
+const char* const kHighsCallbackDataOutMipNodeCountName = "mip_node_count";
+const char* const kHighsCallbackDataOutMipPrimalBoundName = "mip_primal_bound";
+const char* const kHighsCallbackDataOutMipDualBoundName = "mip_dual_bound";
+const char* const kHighsCallbackDataOutMipGapName = "mip_gap";
+const char* const kHighsCallbackDataOutMipSolutionName = "mip_solution";
+const char* const kHighsCallbackDataOutCutpoolNumColName = "cutpool_num_col";
+const char* const kHighsCallbackDataOutCutpoolNumCutName = "cutpool_num_cut";
+const char* const kHighsCallbackDataOutCutpoolNumNzName = "cutpool_num_nz";
+const char* const kHighsCallbackDataOutCutpoolStartName = "cutpool_start";
+const char* const kHighsCallbackDataOutCutpoolIndexName = "cutpool_index";
+const char* const kHighsCallbackDataOutCutpoolValueName = "cutpool_value";
+const char* const kHighsCallbackDataOutCutpoolLowerName = "cutpool_lower";
+const char* const kHighsCallbackDataOutCutpoolUpperName = "cutpool_upper";
 
 #ifdef __cplusplus
 extern "C" {
@@ -274,13 +301,6 @@ HighsInt Highs_versionPatch(void);
  */
 const char* Highs_githash(void);
 
-/**
- * Return the HiGHS compilation date.
- *
- * @returns Thse HiGHS compilation date.
- */
-const char* Highs_compilationDate(void);
-
 /**
  * Read a model from `filename` into `highs`.
  *
@@ -301,6 +321,16 @@ HighsInt Highs_readModel(void* highs, const char* filename);
  */
 HighsInt Highs_writeModel(void* highs, const char* filename);
 
+/**
+ * Write the presolved model in `highs` to `filename`.
+ *
+ * @param highs     A pointer to the Highs instance.
+ * @param filename  The filename to write.
+ *
+ * @returns A `kHighsStatus` constant indicating whether the call succeeded.
+ */
+HighsInt Highs_writePresolvedModel(void* highs, const char* filename);
+
 /**
  * Reset the options and then call `clearModel`.
  *
@@ -2146,10 +2176,29 @@ HighsInt Highs_getRanging(
  */
 void Highs_resetGlobalScheduler(const HighsInt blocking);
 
+/**
+ * Get a void* pointer to a callback data item
+ *
+ * @param data_out      A pointer to the HighsCallbackDataOut instance.
+ * @param item_name     The name of the item.
+ *
+ * @returns A void* pointer to the callback data item, or NULL if item_name not
+ * valid
+ */
+const void* Highs_getCallbackDataOutItem(const HighsCallbackDataOut* data_out,
+                                         const char* item_name);
+
 // *********************
 // * Deprecated methods*
 // *********************
 
+/**
+ * Return the HiGHS compilation date.
+ *
+ * @returns Thse HiGHS compilation date.
+ */
+const char* Highs_compilationDate(void);
+
 // These are deprecated because they don't follow the style guide. Constants
 // must begin with `k`.
 const HighsInt HighsStatuskError = -1;
