@@ -5,6 +5,7 @@ using System.Text;
 
 // mcs -out:highscslib.dll -t:library highs_csharp_api.cs -unsafe
 
+namespace Highs {
 public enum HighsStatus
 {
     kError = -1,
@@ -52,7 +53,8 @@ public enum HighsModelStatus
     kIterationLimit,
     kUnknown,
     kSolutionLimit,
-    kInterrupt
+    kInterrupt,
+    kMemoryLimit
 }
 
 public enum HighsIntegrality
@@ -188,6 +190,9 @@ public class HighsLpSolver : IDisposable
     [DllImport(highslibname)]
     private static extern int Highs_writeModel(IntPtr highs, string filename);
 
+    [DllImport(highslibname)]
+    private static extern int Highs_writePresolvedModel(IntPtr highs, string filename);
+
     [DllImport(highslibname)]
     private static extern int Highs_writeSolutionPretty(IntPtr highs, string filename);
 
@@ -596,6 +601,11 @@ public class HighsLpSolver : IDisposable
         return (HighsStatus)HighsLpSolver.Highs_writeModel(this.highs, filename);
     }
 
+    public HighsStatus writePresolvedModel(string filename)
+    {
+        return (HighsStatus)HighsLpSolver.Highs_writePresolvedModel(this.highs, filename);
+    }
+
     public HighsStatus writeSolutionPretty(string filename)
     {
         return (HighsStatus)HighsLpSolver.Highs_writeSolutionPretty(this.highs, filename);
@@ -908,7 +918,7 @@ public class HighsLpSolver : IDisposable
             MipGap = this.GetValueOrFallback(HighsLpSolver.Highs_getDoubleInfoValue, "mip_gap", double.NaN),
             DualBound = this.GetValueOrFallback(HighsLpSolver.Highs_getDoubleInfoValue, "mip_dual_bound", double.NaN),
             ObjectiveValue = this.GetValueOrFallback(HighsLpSolver.Highs_getDoubleInfoValue, "objective_function_value", double.NaN),
-            NodeCount = this.GetValueOrFallback(HighsLpSolver.Highs_getInt64InfoValue, "mip_node_count", 0l),
+            NodeCount = this.GetValueOrFallback(HighsLpSolver.Highs_getInt64InfoValue, "mip_node_count", 0L),
             IpmIterationCount = this.GetValueOrFallback(HighsLpSolver.Highs_getIntInfoValue, "ipm_iteration_count", 0),
             SimplexIterationCount = this.GetValueOrFallback(HighsLpSolver.Highs_getIntInfoValue, "simplex_iteration_count", 0),
             PdlpIterationCount = this.GetValueOrFallback(HighsLpSolver.Highs_getIntInfoValue, "pdlp_iteration_count", 0),
@@ -1027,3 +1037,4 @@ public class SolutionInfo
     /// </summary>
     public double ObjectiveValue { get; set; }
 }
+}
