@@ -319,8 +319,8 @@ bool hasNamesWithSpaces(const HighsLogOptions& log_options,
                         const std::vector<std::string>& names) {
   HighsInt num_names_with_spaces = 0;
   for (HighsInt ix = 0; ix < num_name; ix++) {
-    HighsInt space_pos = names[ix].find(" ");
-    if (space_pos >= 0) {
+    size_t space_pos = names[ix].find(" ");
+    if (space_pos != std::string::npos) {
       if (num_names_with_spaces == 0) {
         highsLogDev(
             log_options, HighsLogType::kInfo,
@@ -398,10 +398,12 @@ void writeSolutionFile(FILE* file, const HighsOptions& options,
   if (style == kSolutionStyleOldRaw) {
     writeOldRawSolution(file, lp, basis, solution);
   } else if (style == kSolutionStylePretty) {
-    writeModelBoundSolution(
-        file, true, lp.num_col_, lp.col_lower_, lp.col_upper_, lp.col_names_,
-        have_primal, solution.col_value, have_dual, solution.col_dual,
-        have_basis, basis.col_status, lp.integrality_.data());
+    const HighsVarType* integrality =
+        lp.integrality_.size() > 0 ? lp.integrality_.data() : nullptr;
+    writeModelBoundSolution(file, true, lp.num_col_, lp.col_lower_,
+                            lp.col_upper_, lp.col_names_, have_primal,
+                            solution.col_value, have_dual, solution.col_dual,
+                            have_basis, basis.col_status, integrality);
     writeModelBoundSolution(file, false, lp.num_row_, lp.row_lower_,
                             lp.row_upper_, lp.row_names_, have_primal,
                             solution.row_value, have_dual, solution.row_dual,
